@@ -46,12 +46,13 @@ dataset = Dataset.File.upload_directory(
     overwrite=True
 )
 
+output_jsons_path = Path(output_jsons)
 dir_list = [p for p in Path(output_jsons).iterdir() if p.is_dir()]
 
 for dir_path in dir_list:
     dir_name = dir_path.name
-    source = str(output_jsons / dir_name)
-    dummy_path = str(output_jsons / dir_name / 'dummy.json')
+    source = str(output_jsons_path / dir_name)
+    dummy_path = str(output_jsons_path / dir_name / 'dummy.json')
 
     subdir_list = [p for p in Path(source).iterdir() if p.is_dir()]
     subfiles_list = [p for p in Path(source).iterdir() if p.is_file()]
